/** @defgroup fracao
  * Funes para clculos sobre fraes positivas.
  */
#include "mdc.h"
#include "fracao.h"
#include <stdio.h>

/** @brief Cria uma frao
    @detail Cria uma frao dados dois inteiros positivos: o numerador e o
    denominador
    @param numerador um inteiro para o numerador da frao
    @param denominador um inteiro positivo para o denominador da frao
    @return a frao construda
*/
fracao novafr(int numerador, int denominador)
{
    fracao c;
    c.num=numerador;
    c.den=denominador;
    return simplificafr(c);
}

/** @brief Simplifica frao
    @detail Dada uma frao, retorna sua forma simplificada. Utiliza o MDC.
    @param a frao a simplificar
    @return a frao simplificada
*/
fracao simplificafr(fracao a)
{
    int div;
    div=mdc(a.num,a.den);
    a.num/=div;
    a.den/=div;
    return a;
}

/** @brief Soma de fraes.
    @detail dadas duas fraes, retorna sua soma. Utiliza MMC para faz-lo de
    de forma eficiente.
    @param a uma frao
    @param b outra frao
    @return a soma simplificada das fraes.
*/
fracao somafr(fracao a, fracao b)
{
    fracao c;
    c.den=mmc(a.den,b.den);
    c.num=a.num*(c.den/a.den)+b.num*(c.den/b.den);
    return simplificafr(c);
}

/** @brief Produto de fraes.
    @detail Dadas duas fraes, retorna seu produto. Simplifica a frao.
    @param a uma frao
    @param b outra frao
    @return o produto simplificado das fraes.
*/
fracao multfr(fracao a,fracao b)
{
    fracao c;
    c.num=a.num*b.num;
    c.den=a.den*b.den;
    return simplificafr(c);
}

/** @brief Impresso de frao no console.
    @detail Imprime uma frao no console na forma "(a/b)" utilizando printf.
    @param a a frao a ser impressa
*/
void imprimefr(fracao a)
{
    printf("(%d/%d)",a.num,a.den);
}
